@@ -27,8 +27,4 @@ impl RigDriver for Position {
             rotation: params.parent.rotation,
         }
     }
-
-    fn as_any_mut(&mut self) -> &mut dyn std::any::Any {
-        self
-    }
 }
