@@ -21,8 +21,4 @@ impl RigDriver for Rotation {
             rotation: self.rotation,
         }
     }
-
-    fn as_any_mut(&mut self) -> &mut dyn std::any::Any {
-        self
-    }
 }
